Index: wp-admin/includes/image.php
===================================================================
--- wp-admin/includes/image.php	(revision 12527)
+++ wp-admin/includes/image.php	(working copy)
@@ -17,9 +17,12 @@
  *
  * @param mixed $file Filename of the original image, Or attachment id.
  * @param int $max_side Maximum length of a single side for the thumbnail.
+ * @param mixed $deprecated Not used.
  * @return string Thumbnail path on success, Error string on failure.
  */
 function wp_create_thumbnail( $file, $max_side, $deprecated = '' ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
 	$thumbpath = image_resize( $file, $max_side, $max_side );
 	return apply_filters( 'wp_create_thumbnail', $thumbpath );
 }
Index: wp-admin/includes/meta-boxes.php
===================================================================
--- wp-admin/includes/meta-boxes.php	(revision 12527)
+++ wp-admin/includes/meta-boxes.php	(working copy)
@@ -639,6 +639,9 @@
 function xfn_check($class, $value = '', $deprecated = '') {
 	global $link;
 
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	$link_rel = isset( $link->link_rel ) ? $link->link_rel : ''; // In PHP 5.3: $link_rel = $link->link_rel ?: '';
 	$rels = preg_split('/\s+/', $link_rel);
 
Index: wp-admin/includes/upgrade.php
===================================================================
--- wp-admin/includes/upgrade.php	(revision 12527)
+++ wp-admin/includes/upgrade.php	(working copy)
@@ -33,9 +33,12 @@
  * @param null $deprecated Optional. Not used.
  * @return array Array keys 'url', 'user_id', 'password', 'password_message'.
  */
-function wp_install($blog_title, $user_name, $user_email, $public, $deprecated='') {
+function wp_install( $blog_title, $user_name, $user_email, $public, $deprecated = '' ) {
 	global $wp_rewrite;
 
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '2.6' );
+
 	wp_check_mysql_version();
 	wp_cache_flush();
 	make_db_current_silent();
Index: wp-app.php
===================================================================
--- wp-app.php	(revision 12527)
+++ wp-app.php	(working copy)
@@ -884,10 +884,12 @@
 	 *
 	 * @since 2.2.0
 	 *
-	 * @param mixed $deprecated Optional, not used.
+	 * @param mixed $deprecated Not used.
 	 * @return string
 	 */
 	function get_categories_url($deprecated = '') {
+		if ( !empty( $deprecated ) )
+			_deprecated_argument( __FUNCTION__, '2.5' );
 		return $this->app_base . $this->CATEGORIES_PATH;
 	}
 
Index: wp-includes/author-template.php
===================================================================
--- wp-includes/author-template.php	(revision 12538)
+++ wp-includes/author-template.php	(working copy)
@@ -22,6 +22,10 @@
  */
 function get_the_author($deprecated = '') {
 	global $authordata;
+
+	if ( !empty( $deprecated )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	return apply_filters('the_author', is_object($authordata) ? $authordata->display_name : null);
 }
 
@@ -44,11 +48,9 @@
  * @param string $deprecated_echo Deprecated. Use get_the_author(). Echo the string or return it.
  * @return string The author's display name, from get_the_author().
  */
-function the_author($deprecated = '', $deprecated_echo = true) {
-	if ( !empty($deprecated) )
-		_deprecated_argument(__FUNCTION__, 'deprecated', '1.5');
-	if ( $deprecated_echo !== true )
-		_deprecated_argument(__FUNCTION__, 'deprecated_echo', '1.5', __('Use get_the_author() instead if you do not want the value echoed.'));
+function the_author( $deprecated = '', $deprecated_echo = true ) {
+	if ( !empty( $deprecated ) || $deprecated_echo !== true )
+		_deprecated_argument( __FUNCTION__, '1.5', $deprecated_echo !== true ? __('Use get_the_author() instead if you do not want the value echoed.') : null );
 	if ( $deprecated_echo )
 		echo get_the_author();
 	return get_the_author();
@@ -182,7 +184,7 @@
  */
 function the_author_posts_link($deprecated = '') {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument(__FUNCTION__, 'deprecated', '0.0');
+		_deprecated_argument( __FUNCTION__, '0.0' );
 
 	global $authordata;
 	$link = sprintf(
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 12538)
+++ wp-includes/comment.php	(working copy)
@@ -1511,9 +1511,9 @@
  * @param int $deprecated Not Used.
  * @return bool|string False on failure, string containing URI on success.
  */
-function discover_pingback_server_uri($url, $deprecated = '') {
-	if ( !empty($deprecated) )
-		_deprecated_argument(__FUNCTION__, 'deprecated', '0.0');
+function discover_pingback_server_uri( $url, $deprecated = '' ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
 
 	$pingback_str_dquote = 'rel="pingback"';
 	$pingback_str_squote = 'rel=\'pingback\'';
Index: wp-includes/cron.php
===================================================================
--- wp-includes/cron.php	(revision 12538)
+++ wp-includes/cron.php	(working copy)
@@ -136,7 +136,7 @@
 	// Backward compatibility
 	// Previously this function took the arguments as discrete vars rather than an array like the rest of the API
 	if ( !is_array($args) ) {
-		_deprecated_argument(__FUNCTION__, 'args', '3.0.0', __('This argument has changed to an array so as to match with the behaviour of all the other cron functions.') );
+		_deprecated_argument( __FUNCTION__, '3.0.0', __('This argument has changed to an array to match the behavior of the other cron functions.') );
 		$args = array_slice( func_get_args(), 1 );
 	}
 
Index: wp-includes/formatting.php
===================================================================
--- wp-includes/formatting.php	(revision 12538)
+++ wp-includes/formatting.php	(working copy)
@@ -866,6 +866,9 @@
  * @return string Converted string.
  */
 function convert_chars($content, $deprecated = '') {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	// Translation of invalid Unicode references range to valid range
 	$wp_htmltranswinuni = array(
 	'&#128;' => '&#8364;', // the Euro sign
Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 12538)
+++ wp-includes/functions.php	(working copy)
@@ -570,6 +570,9 @@
  * @return null returns when finished.
  */
 function add_option( $name, $value = '', $deprecated = '', $autoload = 'yes' ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '2.3' );
+
 	global $wpdb;
 
 	wp_protect_special_option( $name );
@@ -1188,6 +1191,9 @@
  * @return bool|string False on failure and string of headers if HEAD request.
  */
 function wp_get_http( $url, $file_path = false, $deprecated = false ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	@set_time_limit( 60 );
 
 	$options = array();
@@ -1230,6 +1236,9 @@
  * @return bool|string False on failure, headers on success.
  */
 function wp_get_http_headers( $url, $deprecated = false ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	$response = wp_remote_head( $url );
 
 	if ( is_wp_error( $response ) )
@@ -2172,6 +2181,9 @@
  * @return array
  */
 function wp_upload_bits( $name, $deprecated, $bits, $time = null ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	if ( empty( $name ) )
 		return array( 'error' => __( 'Empty filename' ) );
 
@@ -3017,7 +3029,7 @@
  * For example:
  * <code>
  * if ( !empty($deprecated) )
- * 	_deprecated_argument( __FUNCTION__, 'deprecated', '0.0' );
+ * 	_deprecated_argument( __FUNCTION__, '0.0' );
  * </code>
  *
  * There is a hook deprecated_argument_run that will be called that can be used
@@ -3031,24 +3043,23 @@
  * @since 3.0.0
  * @access private
  *
- * @uses do_action() Calls 'deprecated_argument_run' and passes the function and argument names and what to use instead.
+ * @uses do_action() Calls 'deprecated_argument_run' and passes the function name and what to use instead.
  * @uses apply_filters() Calls 'deprecated_argument_trigger_error' and expects boolean value of true to do trigger or false to not trigger error.
  *
  * @param string $function The function that was called
- * @param string $argument The name of the deprecated argument that was used
- * @param string $version The version of WordPress that deprecated the function
+ * @param string $version The version of WordPress that deprecated the argument used
  * @param string $message Optional. A message regarding the change.
  */
-function _deprecated_argument($function, $argument, $version, $message = null) {
+function _deprecated_argument($function, $version, $message = null) {
 
-	do_action('deprecated_argument_run', $function, $argument, $message);
+	do_action('deprecated_argument_run', $function, $message);
 
 	// Allow plugin to filter the output error trigger
 	if( WP_DEBUG && apply_filters( 'deprecated_argument_trigger_error', true ) ) {
 		if( !is_null($message) )
-			trigger_error( sprintf( __('The %1$s argument of %2$s is <strong>deprecated</strong> since version %3$s! %4$s'), $function, $argument, $version, $message ) );
+			trigger_error( sprintf( __('%1$s was called with an argument that is <strong>deprecated</strong> since version %2$s! %3$s'), $function, $version, $message ) );
 		else
-			trigger_error( sprintf( __('The %1$s argument of %2$s is <strong>deprecated</strong> since version %3$s with no alternative available.'), $function, $argument, $version ) );
+			trigger_error( sprintf( __('%1$s was called with an argument that is <strong>deprecated</strong> since version %2$s with no alternative available.'), $function, $argument, $version ) );
 	}
 }
 
Index: wp-includes/kses.php
===================================================================
--- wp-includes/kses.php	(revision 12538)
+++ wp-includes/kses.php	(working copy)
@@ -1197,6 +1197,9 @@
 add_action('set_current_user', 'kses_init');
 
 function safecss_filter_attr( $css, $deprecated = '' ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	$css = wp_kses_no_null($css);
 	$css = str_replace(array("\n","\r","\t"), '', $css);
 
Index: wp-includes/link-template.php
===================================================================
--- wp-includes/link-template.php	(revision 12538)
+++ wp-includes/link-template.php	(working copy)
@@ -168,7 +168,10 @@
  * @param mixed $deprecated Not used.
  * @return string
  */
-function post_permalink($post_id = 0, $deprecated = '') {
+function post_permalink( $post_id = 0, $deprecated = '' ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	return get_permalink($post_id);
 }
 
Index: wp-includes/post-template.php
===================================================================
--- wp-includes/post-template.php	(revision 12538)
+++ wp-includes/post-template.php	(working copy)
@@ -245,9 +245,9 @@
  * @param mixed $deprecated Not used.
  * @return string
  */
-function get_the_excerpt($deprecated = '') {
+function get_the_excerpt( $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument(__FUNCTION__, 'deprecated', '2.3');
+		_deprecated_argument( __FUNCTION__, '2.3' );
 
 	global $post;
 	$output = $post->post_excerpt;
@@ -900,7 +900,10 @@
  * @param bool $deprecated Deprecated. Not used.
  * @param bool $permalink Optional, default is false. Whether to include permalink.
  */
-function the_attachment_link($id = 0, $fullsize = false, $deprecated = false, $permalink = false) {
+function the_attachment_link( $id = 0, $fullsize = false, $deprecated = false, $permalink = false ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	if ( $fullsize )
 		echo wp_get_attachment_link($id, 'full', $permalink);
 	else
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 12538)
+++ wp-includes/post.php	(working copy)
@@ -3538,9 +3538,11 @@
  * @param int $deprecated Not Used. Can be set to null.
  * @param object $post Object type containing the post information
  */
-function _future_post_hook($deprecated = '', $post) {
+function _future_post_hook( $deprecated = '', $post ) {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
 	wp_clear_scheduled_hook( 'publish_future_post', array( $post->ID ) );
-	wp_schedule_single_event(strtotime($post->post_date_gmt. ' GMT'), 'publish_future_post', array($post->ID));
+	wp_schedule_single_event( strtotime( $post->post_date_gmt. ' GMT' ), 'publish_future_post', array( $post->ID ) );
 }
 
 /**
Index: wp-includes/widgets.php
===================================================================
--- wp-includes/widgets.php	(revision 12538)
+++ wp-includes/widgets.php	(working copy)
@@ -985,7 +985,7 @@
  */
 function wp_get_sidebars_widgets($deprecated = true) {
 	if ( $deprecated !== true )
-		_deprecated_argument(__FUNCTION__, 'deprecated', '0.0');
+		_deprecated_argument( __FUNCTION__, '0.0' );
 
 	global $wp_registered_widgets, $wp_registered_sidebars, $_wp_sidebars_widgets;
 

Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 12538)
+++ wp-includes/comment-template.php	(working copy)
@@ -507,11 +507,8 @@
  * @param bool $deprecated_2 Not Used
  */
 function comments_link( $deprecated_1 = '', $deprecated_2 = '' ) {
-	if ( !empty( $deprecated_1 ) )
-		_deprecated_argument(__FUNCTION__, 'deprecated_1', '0.0');
-	if ( !empty( $deprecated_2 ) )
-		_deprecated_argument(__FUNCTION__, 'deprecated_2', '0.0');
-
+	if ( !empty( $deprecated_1 ) || empty( $deprecated_2 ) )
+		_deprecated_argument( __FUNCTION__, '0.0' );
 	echo get_comments_link();
 }
 
@@ -554,6 +551,10 @@
  */
 function comments_number( $zero = false, $one = false, $more = false, $deprecated = '' ) {
 	global $id;
+
+	if ( !empty( $deprecated )
+		_deprecated_argument( __FUNCTION__, '0.0' );
+
 	$number = get_comments_number($id);
 
 	if ( $number > 1 )
@@ -696,12 +697,16 @@
  * @since 0.71
  * @uses get_trackback_url() Gets the trackback url for the current post
  *
  * @param bool $deprecated Remove backwards compat in 2.5
  * @return void|string Should only be used to echo the trackback URL, use get_trackback_url() for the result instead.
  */
-function trackback_url($deprecated = true) {
-	if ($deprecated) echo get_trackback_url();
-	else return get_trackback_url();
+function trackback_url( $deprecated_echo = true ) {
+	if ( $deprecated_echo !== true )
+		_deprecated_argument( __FUNCTION__, '2.5', __('Use get_trackback_url() instead if you do not want the value echoed.') );
+	if ( $deprecated_echo )
+		echo get_trackback_url();
+	else
+		return get_trackback_url();
 }
 
 /**
@@ -712,6 +717,9 @@
  * @param int $deprecated Not used (Was $timezone = 0)
  */
 function trackback_rdf($deprecated = '') {
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '2.5' );
+
 	if (stripos($_SERVER['HTTP_USER_AGENT'], 'W3C_Validator') === false) {
 		echo '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
 				xmlns:dc="http://purl.org/dc/elements/1.1/"
@@ -696,12 +697,16 @@
  * @uses get_trackback_url() Gets the trackback url for the current post
  *
- * @param bool $deprecated Remove backwards compat in 2.5
+ * @param bool $deprecated_echo Remove backwards compat in 2.5
  * @return void|string Should only be used to echo the trackback URL, use get_trackback_url() for the result instead.
  */